@@ -1,9 +1,4 @@
 import os
-from aws_pcluster_helpers.models.sinfo import SInfoTable, SinfoRow
-from aws_pcluster_helpers.models import nextflow
-from rich.console import Console
-from rich.table import Table
-import sys
 from prefect import Flow, task
 from prefect.tasks.shell import ShellTask
 import time
